@@ -4,7 +4,7 @@ These files are reported as candidates for removal.
 
 """
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 
 import argparse
@@ -86,16 +86,20 @@ def unreferenced_files(path, exclude_referrers):
 
 
 def main():
-    """Entry point."""
+    """Return nonzero error code if unreferenced files are found."""
     parser = argparse.ArgumentParser()
-    parser.add_argument('paths', nargs='+')
+    parser.add_argument('directories', nargs='+')
     parser.add_argument('--exclude-referrers', default='',
                         help='comma-separated list of files to exclude as '
                              'referrers')
     args = parser.parse_args()
 
-    for filename in args.paths:
+    total = 0
+    for filename in args.directories:
         for name in unreferenced_files(
                 filename,
                 exclude_referrers=args.exclude_referrers.split(',')):
             print(name)
+            total += 1
+
+    return 2 if total else 0
